sequencetools.yield_all_combinations_of_elements
================================================

.. autofunction:: abjad.tools.sequencetools.yield_all_combinations_of_elements.yield_all_combinations_of_elements
